@@ -20,8 +20,8 @@
 #include <strings.h>
 #include <stdio.h>
 
-#define Q_DIV / 2
-#define Q_MUL * 2
+#define Q_DIV(X) ((X) / 2)
+#define Q_MUL(X) ((X) * 2)
 #define DEV_QBSIZE DEV_BSIZE
 #define CADR
 
